@@ -12,14 +12,11 @@ Geo::Coder::Many::Mapquest - Mapquest plugin Geo::Coder::Many
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
-
-# Requires Geo::Coder::Mapquest 0.05 or above
-sub _MIN_MODULE_VERSION { return '0.05'; }
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -59,8 +56,8 @@ This is called by Geo::Coder::Many - it sends the geocoding request (via
 Geo::Coder::Mapquest) and extracts the resulting location, returning it in a
 standard Geo::Coder::Many::Response.
 
-NOTE: currently precision is hard coded to undef! We need to fix it to
-interpret the code returned by mapquest and assigning a meaningful
+NOTE: currently precision is hard coded to 1! This is obviously wrong, need 
+to fix it to interpret the code returned by mapquest and assigning a meaningful
 precision
 
 =cut
@@ -74,6 +71,8 @@ sub geocode {
     my @raw_replies = $self->{GeoCoder}->geocode( location => $location );
     my $response = Geo::Coder::Many::Response->new( { location => $location } );
 
+    my $location_data = [];
+
     foreach my $raw_reply ( @raw_replies ) {
 
 
@@ -100,12 +99,11 @@ sub _determine_precision {
     my $self = shift;
     my $code = shift;
 
-    my $precision = undef; # FIXME!
-    # for now all precision set to undef (ie we dont know)
+    # for now all precision set to 1,
     # should instead be converting to meaningful number between 0 and 1
     # based on code
     # see http://www.mapquestapi.com/geocoding/geocodequality.html
-    return $precision; 
+    return 1;  # FIXME!
 }
 
 =head2 get_name
@@ -114,8 +112,6 @@ Returns the name of the geocoder type - used by Geo::Coder::Many
 
 =cut
 
-sub get_name { my $self = shift; return 'mapquest ' . $self->{GeoCoder}->VERSION; }
+sub get_name { return 'mapquest'; }
 
 1; 
-
-__END__
